@@ -223,22 +223,22 @@ class Parser:
                     else:
                         for db_table in queried_cols:
                             for k,v in db_table.items():
-                                if var in v:
+                                if var in v[0]:
                                     original_columns_list.append("{}.{}".format(k, var))
 
                 elif len(var_split) == 2:
 
-                    if var_split[0] in table_alias_mapping.keys():
-                        db_table = table_alias_mapping[var_split[0]]
-                    
-                        for db_table_col in queried_cols:
-                            for k,v in db_table_col.items():
+                    if '.'.join(var_split[:2]) in table_alias_mapping.keys():
+                        db_table = '.'.join(var_split[:2])
+            
+                    for db_table_col in queried_cols:
+                        for k,v in db_table_col.items():
 
-                                if k == db_table and var_split[1] in v:
-                                    original_columns_list.append("{}.{}".format(k, var_split[1]))
-                                elif k == db_table and var_split[1] == '*':
-                                    for col in v:
-                                        original_columns_list.append("{}.{}".format(k, col))     
+                            if k == db_table and var_split[2] in v[0]:
+                                original_columns_list.append("{}.{}".format(k, var_split[2]))
+                            elif k == db_table and var_split[2] == '*':
+                                for col in v[0]:
+                                    original_columns_list.append("{}.{}".format(k, col))   
 
         return list(set(original_columns_list))
             
